build: strip release binaries

This significantly reduces binary size for deltachat-rpc-server,
from 42 MiB to 15 MiB in case of aarch64.
This commit is contained in:
link2xt
2023-10-22 13:13:04 +00:00
parent b4fe9e3eec
commit 418cd24979
+1
View File
@@ -24,6 +24,7 @@ lto = true
panic = 'abort'
opt-level = "z"
codegen-units = 1
strip = true
[patch.crates-io]
quinn-udp = { git = "https://github.com/quinn-rs/quinn", branch="main" }